pub enum Error {
Module,
OutOfBounds,
Execution,
}Expand description
Error that can occur while using this crate.
Variants
Module
Module is not valid, couldn’t be instantiated.
OutOfBounds
Access to a memory or table was made with an address or an index which is out of bounds.
Note that if wasm module makes an out-of-bounds access then trap will occur.
Execution
Failed to invoke the start function or an exported function for some reason.