EnvironmentDefinitionBuilder

Struct EnvironmentDefinitionBuilder 

pub struct EnvironmentDefinitionBuilder<T> { /* private fields */ }
Struct that can be used for defining an environment for a sandboxed module.

The sandboxed module can access only the entities which were defined and passed to the module at the instantiation time.

Implementations

Source

impl<T> EnvironmentDefinitionBuilder<T>

pub fn new() -> EnvironmentDefinitionBuilder<T>

Construct a new EnvironmentDefinitionBuilder.

pub fn add_host_func<N1, N2>( &mut self, module: N1, field: N2, f: HostFuncType<T>, )
where N1: Into<Vec<u8>>, N2: Into<Vec<u8>>,

Register a host function in this environment definition.

NOTE that there is no constraints on type of this function. An instance can import function passed here with any signature it wants. It can even import the same function (i.e. with same module and field) several times. It’s up to the user code to check or constrain the types of signatures.

pub fn add_memory<N1, N2>(&mut self, module: N1, field: N2, mem: Memory)
where N1: Into<Vec<u8>>, N2: Into<Vec<u8>>,

Register a memory in this environment definition.