pub struct Instance<T> { /* private fields */ }Expand description
Sandboxed instance of a wasm module.
This instance can be used for invoking exported functions.
Implementations
Sourceimpl<T> Instance<T>
impl<T> Instance<T>
Sourcepub fn new(
code: &[u8],
env_def_builder: &EnvironmentDefinitionBuilder<T>,
state: &mut T,
) -> Result<Instance<T>, Error>
pub fn new( code: &[u8], env_def_builder: &EnvironmentDefinitionBuilder<T>, state: &mut T, ) -> Result<Instance<T>, Error>
Instantiate a module with the given EnvironmentDefinitionBuilder. It will
run the start function (if it is present in the module) with the given state.
Returns Err(Error::Module) if this module can’t be instantiated with the given
environment. If execution of start function generated a trap, then Err(Error::Execution) will
be returned.
Sourcepub fn invoke(
&mut self,
name: &str,
args: &[Value],
state: &mut T,
) -> Result<ReturnValue, Error>
pub fn invoke( &mut self, name: &str, args: &[Value], state: &mut T, ) -> Result<ReturnValue, Error>
Invoke an exported function with the given name.
Errors
Returns Err(Error::Execution) if:
- An export function name isn’t a proper utf8 byte sequence,
- This module doesn’t have an exported function with the given name,
- If types of the arguments passed to the function doesn’t match function signature then trap occurs (as if the exported function was called via call_indirect),
- Trap occurred at the execution time.
Sourcepub fn get_global_val(&self, name: &str) -> Option<Value>
pub fn get_global_val(&self, name: &str) -> Option<Value>
Get the value from a global with the given name.
Returns Some(_) if the global could be found.