pub struct Memory { /* private fields */ }Expand description
Implementations
Sourceimpl Memory
impl Memory
Sourcepub fn new(initial: u32, maximum: Option<u32>) -> Result<Memory, Error>
pub fn new(initial: u32, maximum: Option<u32>) -> Result<Memory, Error>
Construct a new linear memory instance.
The memory allocated with initial number of pages specified by initial.
Minimal possible value for initial is 0 and maximum possible is 65536.
(Since maximum addressable memory is 232 = 4GiB = 65536 * 64KiB).
It is possible to limit maximum number of pages this memory instance can have by specifying
maximum. If not specified, this memory instance would be able to allocate up to 4GiB.
Allocated memory is always zeroed.